@@ -1,21 +1,21 @@
 /*
- * This file is part of gspell.
+ * This file is part of gspell, a spell-checking library.
  *
  * Copyright 2002 - Paolo Maggi
  * Copyright 2015 - Sébastien Wilmet
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -35,11 +35,6 @@
 
 typedef struct _GspellCheckerDialogPrivate GspellCheckerDialogPrivate;
 
-struct _GspellCheckerDialog
-{
-	GtkDialog parent_instance;
-};
-
 struct _GspellCheckerDialogPrivate
 {
 	GspellNavigator *navigator;
@@ -92,7 +87,7 @@ set_spell_checker (GspellCheckerDialog *dialog,
 		lang = gspell_checker_get_language (checker);
 
 		gtk_header_bar_set_subtitle (header_bar,
-					     gspell_language_to_string (lang));
+					     gspell_language_get_name (lang));
 	}
 }
 
@@ -105,7 +100,7 @@ set_navigator (GspellCheckerDialog *dialog,
 	priv = gspell_checker_dialog_get_instance_private (dialog);
 
 	g_return_if_fail (priv->navigator == NULL);
-	priv->navigator = g_object_ref (navigator);
+	priv->navigator = g_object_ref_sink (navigator);
 
 	g_object_notify (G_OBJECT (dialog), "spell-navigator");
 }
@@ -189,7 +184,7 @@ set_misspelled_word (GspellCheckerDialog *dialog,
 
 	priv = gspell_checker_dialog_get_instance_private (dialog);
 
-	g_return_if_fail (!gspell_checker_check_word (priv->checker, word, NULL));
+	g_return_if_fail (!gspell_checker_check_word (priv->checker, word, -1, NULL));
 
 	g_free (priv->misspelled_word);
 	priv->misspelled_word = g_strdup (word);
@@ -198,7 +193,7 @@ set_misspelled_word (GspellCheckerDialog *dialog,
 	gtk_label_set_markup (priv->misspelled_word_label, label);
 	g_free (label);
 
-	suggestions = gspell_checker_get_suggestions (priv->checker, priv->misspelled_word);
+	suggestions = gspell_checker_get_suggestions (priv->checker, priv->misspelled_word, -1);
 
 	set_suggestions (dialog, suggestions);
 
@@ -257,8 +252,7 @@ goto_next (GspellCheckerDialog *dialog)
 	if (error != NULL)
 	{
 		show_error (dialog, error);
-		g_error_free (error);
-		error = NULL;
+		g_clear_error (&error);
 	}
 	else if (found)
 	{
@@ -296,14 +290,12 @@ gspell_checker_dialog_get_property (GObject    *object,
 				    GValue     *value,
 				    GParamSpec *pspec)
 {
-	GspellCheckerDialogPrivate *priv;
-
-	priv = gspell_checker_dialog_get_instance_private (GSPELL_CHECKER_DIALOG (object));
+	GspellCheckerDialog *dialog = GSPELL_CHECKER_DIALOG (object);
 
 	switch (prop_id)
 	{
 		case PROP_SPELL_NAVIGATOR:
-			g_value_set_object (value, priv->navigator);
+			g_value_set_object (value, gspell_checker_dialog_get_spell_navigator (dialog));
 			break;
 
 		default:
@@ -480,7 +472,7 @@ check_word_button_clicked_handler (GtkButton           *button,
 
 	word = gtk_entry_get_text (priv->word_entry);
 
-	correctly_spelled = gspell_checker_check_word (priv->checker, word, &error);
+	correctly_spelled = gspell_checker_check_word (priv->checker, word, -1, &error);
 
 	if (error != NULL)
 	{
@@ -513,7 +505,7 @@ check_word_button_clicked_handler (GtkButton           *button,
 	{
 		GSList *suggestions;
 
-		suggestions = gspell_checker_get_suggestions (priv->checker, word);
+		suggestions = gspell_checker_get_suggestions (priv->checker, word, -1);
 
 		set_suggestions (dialog, suggestions);
 
@@ -531,7 +523,7 @@ add_word_button_clicked_handler (GtkButton           *button,
 
 	g_return_if_fail (priv->misspelled_word != NULL);
 
-	gspell_checker_add_word_to_personal (priv->checker, priv->misspelled_word);
+	gspell_checker_add_word_to_personal (priv->checker, priv->misspelled_word, -1);
 
 	goto_next (dialog);
 }
@@ -553,7 +545,7 @@ ignore_all_button_clicked_handler (GtkButton           *button,
 
 	g_return_if_fail (priv->misspelled_word != NULL);
 
-	gspell_checker_add_word_to_session (priv->checker, priv->misspelled_word);
+	gspell_checker_add_word_to_session (priv->checker, priv->misspelled_word, -1);
 
 	goto_next (dialog);
 }
@@ -563,19 +555,21 @@ change_button_clicked_handler (GtkButton           *button,
 			       GspellCheckerDialog *dialog)
 {
 	GspellCheckerDialogPrivate *priv;
+	const gchar *entry_text;
 	gchar *change_to;
 
 	priv = gspell_checker_dialog_get_instance_private (dialog);
 
 	g_return_if_fail (priv->misspelled_word != NULL);
 
-	change_to = g_strdup (gtk_entry_get_text (priv->word_entry));
-	g_return_if_fail (change_to != NULL);
-	g_return_if_fail (change_to[0] != '\0');
+	entry_text = gtk_entry_get_text (priv->word_entry);
+	g_return_if_fail (entry_text != NULL);
+	g_return_if_fail (entry_text[0] != '\0');
 
+	change_to = g_strdup (entry_text);
 	gspell_checker_set_correction (priv->checker,
-				       priv->misspelled_word,
-				       change_to);
+				       priv->misspelled_word, -1,
+				       change_to, -1);
 
 	gspell_navigator_change (priv->navigator, priv->misspelled_word, change_to);
 	g_free (change_to);
@@ -602,19 +596,21 @@ change_all_button_clicked_handler (GtkButton           *button,
 				   GspellCheckerDialog *dialog)
 {
 	GspellCheckerDialogPrivate *priv;
+	const gchar *entry_text;
 	gchar *change_to;
 
 	priv = gspell_checker_dialog_get_instance_private (dialog);
 
 	g_return_if_fail (priv->misspelled_word != NULL);
 
-	change_to = g_strdup (gtk_entry_get_text (priv->word_entry));
-	g_return_if_fail (change_to != NULL);
-	g_return_if_fail (change_to[0] != '\0');
+	entry_text = gtk_entry_get_text (priv->word_entry);
+	g_return_if_fail (entry_text != NULL);
+	g_return_if_fail (entry_text[0] != '\0');
 
+	change_to = g_strdup (entry_text);
 	gspell_checker_set_correction (priv->checker,
-				       priv->misspelled_word,
-				       change_to);
+				       priv->misspelled_word, -1,
+				       change_to, -1);
 
 	gspell_navigator_change_all (priv->navigator, priv->misspelled_word, change_to);
 	g_free (change_to);
@@ -725,4 +721,21 @@ gspell_checker_dialog_new (GtkWindow       *parent,
 			     NULL);
 }
 
+/**
+ * gspell_checker_dialog_get_spell_navigator:
+ * @dialog: a #GspellCheckerDialog.
+ *
+ * Returns: (transfer none): the #GspellNavigator used.
+ */
+GspellNavigator *
+gspell_checker_dialog_get_spell_navigator (GspellCheckerDialog *dialog)
+{
+	GspellCheckerDialogPrivate *priv;
+
+	g_return_val_if_fail (GSPELL_IS_CHECKER_DIALOG (dialog), NULL);
+
+	priv = gspell_checker_dialog_get_instance_private (dialog);
+	return priv->navigator;
+}
+
 /* ex:set ts=8 noet: */
